==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXWebInfoFilesControl.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXWebInfoFilesControl;no warnings;($serviceMonitoringDelay=
(0x2048+ 3941-0x219d));($serviceStatus=(0x06ef+ 6392-0x1fe7));($lastCheckTime=
(0x16fc+  45-0x1729));($infoFilesDirectory=(((((($GLOBAL::VAR_ROOT.
$GLOBAL::DIRECTORY_SLASH)."\x74\x6d\x70").$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x77\x65\x62\x70\x6c\x61\x79\x65\x72").$GLOBAL::DIRECTORY_SLASH).
"\x69\x6e\x66\x6f"));sub BEGIN{require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub enableService{if ((
isServiceEnabled ()!=(0x154d+ 2589-0x1f69))){init ();}($serviceStatus=
(0x066f+ 766-0x096c));return;}sub disableService{if ((isServiceEnabled ()==
(0x1830+ 3028-0x2403))){deleteAllInfoFiles ();}($serviceStatus=
(0x190b+ 3501-0x26b8));return;}sub isServiceEnabled{return ($serviceStatus);}sub
 init{($lastCheckTime=Common::NXTime::getSecondsSinceEpoch ());return;}sub 
__checkIsTimeForRemoveInfoFiles{(my $currentTime=
Common::NXTime::getSecondsSinceEpoch ());(my $delay=$serviceMonitoringDelay);if 
((($lastCheckTime+$delay)<=$currentTime)){($lastCheckTime=$currentTime);return (
(0x0650+ 2336-0x0f6f));}return ((0x0eb6+ 3468-0x1c42));}sub checkService{if ((
isServiceEnabled ()!=(0x1bff+ 821-0x1f33))){return ((0x1334+ 3440-0x20a3));}if (
(__checkIsTimeForRemoveInfoFiles ()==(0x08b5+ 5240-0x1d2d))){return (
(0x184f+ 1736-0x1f16));}if ((not (Common::NXFile::directoryExists (
$infoFilesDirectory)))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));return;}
foreach my $name (split ( /\n/ ,$list,(0x03eb+ 2138-0x0c45))){if (($name=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$name));(my $fileCTime
=Common::NXCore::NXFileCTime ($path));if ((checkAndRemoveInfoFile ($fileCTime)==
(0x1831+ 3775-0x26ef))){deleteInfoFile ($name);}}}return;}sub 
checkAndRemoveInfoFile{(my $cTime=(shift (@_)||(0x214a+ 532-0x235e)));if ((
$cTime<=(0x1a46+ 3003-0x2601))){return;}if ((($cTime+$serviceMonitoringDelay)<
Common::NXTime::getSecondsSinceEpoch ())){return ((0x10ed+ 4289-0x21ad));}
Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x41\x6e\x64\x52\x65\x6d\x6f\x76\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x20\x46\x69\x6c\x65\x20\x6e\x6f\x74\x20\x72\x65\x61\x64\x79\x20\x74\x6f\x20\x72\x65\x6d\x6f\x76\x65\x2e"
);return ((0x01fd+ 8381-0x22ba));}sub deleteAllInfoFiles{Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);if ((not (Common::NXFile::directoryExists ($infoFilesDirectory)))){(my $errorString
=libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));}foreach my $name
 (split ( /\n/ ,$list,(0x0143+ 6066-0x18f5))){deleteInfoFile ($name);}return;}
sub deleteInfoFile{(my $filename=(shift (@_)||("")));Logger::debug2 (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x28"
.$filename)."\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"));if (($filename=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$filename));if ((
libnxh::NXFileExists ($path)==(0x0f29+ 4134-0x1f4e))){if ((libnxh::NXFileRemove 
($path)!=(0x0065+ 7241-0x1cae))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::warning (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x66\x69\x6c\x65\x20\x27"
.$path)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").$errorNumber).
"\x2c\x20").$errorString)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path)."\x27\x20\x72\x65\x6d\x6f\x76\x65\x64\x2e"));}}else{(my $errorString=
libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug2 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path).
"\x27\x20\x64\x6f\x65\x73\x6e\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20"
).$errorNumber)."\x2c\x20").$errorString)."\x2e"));}}return;}sub 
setInfoDirectoryPermissionByAdmin{Logger::debug (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x73\x65\x74\x49\x6e\x66\x6f\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x42\x79\x41\x64\x6d\x69\x6e\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);main::nxrequire (
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73");if ((not (
NXSystemDaemons::isHttpdEnabledInLicenceAndConfig ()))){return;}if ((not (
main::effectiveUserIsAdministrator ()))){return;}if ((not (
Common::NXFile::directoryExists ($infoFilesDirectory)))){my ($errorMsg);if ((not
 (Common::NXPaths::makePath ((\$errorMsg),$infoFilesDirectory)))){
Logger::warning (((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorMsg)
."\x2e"));return ((0x1e78+ 367-0x1fe6));}}my ($errorNumber);my ($errorString);(my $silent
=(0x0bc1+ 2020-0x13a4));(my $permissions=((($NXBits::UserReadWrite+
$NXBits::UserExecute)+$NXBits::GroupReadWrite)+$NXBits::GroupExecute));if ((
Common::NXFile::setPermissions_unix ($infoFilesDirectory,$permissions,(
\$errorNumber),(\$errorString),$silent)==(-(0x08b2+ 1874-0x1003)))){
Logger::debug (((((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x61\x63\x63\x65\x73\x73\x20\x72\x69\x67\x68\x74\x73\x3a\x20"
.$infoFilesDirectory)."\x20\x74\x6f\x20").$permissions).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorNumber)."\x2c\x20").
$errorString)."\x2e"));}(my $ApacheUname=(""));if (($GLOBAL::ApacheUname ne ("")
)){($ApacheUname=$GLOBAL::ApacheUname);}else{(my (@htdUsers)=
NXTools::getNXHtdUser ());($ApacheUname=$htdUsers[(0x15fb+ 3325-0x22f8)]);}(my $uid
=Common::NXCore::userInfoGetUidByUsername ($ApacheUname));(my $gid=
Common::NXCore::userInfoGetGidByUsername ("\x6e\x78"));if ((
Common::NXFile::setOwnershipForUser_unix ($infoFilesDirectory,$uid,$gid,(
\$errorString),(\$errorNumber),$silen)==(-(0x0f0f+ 4268-0x1fba)))){Logger::debug
 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x6f\x77\x6e\x65\x72\x20\x6f\x66\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return;}"\x3f\x3f\x3f";

==> nomachine-8.3.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXWebInfoFilesControl.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXWebInfoFilesControl;no warnings;($serviceMonitoringDelay=
(0x2029+ 1029-0x161e));($serviceStatus=(0x1cd0+ 1668-0x2354));($lastCheckTime=
(0x03d3+ 7681-0x21d4));($infoFilesDirectory=(((((($GLOBAL::VAR_ROOT.
$GLOBAL::DIRECTORY_SLASH)."\x74\x6d\x70").$GLOBAL::DIRECTORY_SLASH).
"\x6e\x78\x77\x65\x62\x70\x6c\x61\x79\x65\x72").$GLOBAL::DIRECTORY_SLASH).
"\x69\x6e\x66\x6f"));sub BEGIN{require warnings;do{
"\x77\x61\x72\x6e\x69\x6e\x67\x73"->import};}sub enableService{if ((
isServiceEnabled ()!=(0x07eb+ 2538-0x11d4))){init ();}($serviceStatus=
(0x0279+ 203-0x0343));return;}sub disableService{if ((isServiceEnabled ()==
(0x1782+ 380-0x18fd))){deleteAllInfoFiles ();}($serviceStatus=
(0x1028+ 1047-0x143f));return;}sub isServiceEnabled{return ($serviceStatus);}sub
 init{($lastCheckTime=Common::NXTime::getSecondsSinceEpoch ());return;}sub 
__checkIsTimeForRemoveInfoFiles{(my $currentTime=
Common::NXTime::getSecondsSinceEpoch ());(my $delay=$serviceMonitoringDelay);if 
((($lastCheckTime+$delay)<=$currentTime)){($lastCheckTime=$currentTime);return (
(0x1493+ 3333-0x2197));}return ((0x1b4f+  77-0x1b9c));}sub checkService{if ((
isServiceEnabled ()!=(0x0057+ 7378-0x1d28))){return ((0x217c+ 591-0x23ca));}if (
(__checkIsTimeForRemoveInfoFiles ()==(0x06b2+ 7839-0x2551))){return (
(0x06cd+ 8175-0x26bb));}if ((not (Common::NXFile::directoryExists (
$infoFilesDirectory)))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x53\x65\x72\x76\x69\x63\x65\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));return;}
foreach my $name (split ( /\n/ ,$list,(0x0224+ 8075-0x21af))){if (($name=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$name));(my $fileCTime
=Common::NXCore::NXFileCTime ($path));if ((checkAndRemoveInfoFile ($fileCTime)==
(0x1481+ 603-0x16db))){deleteInfoFile ($name);}}}return;}sub 
checkAndRemoveInfoFile{(my $cTime=(shift (@_)||(0x04bc+ 5863-0x1ba3)));if ((
$cTime<=(0x00f4+ 8713-0x22fd))){return;}if ((($cTime+$serviceMonitoringDelay)<
Common::NXTime::getSecondsSinceEpoch ())){return ((0x08e1+ 6310-0x2186));}
Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x63\x68\x65\x63\x6b\x41\x6e\x64\x52\x65\x6d\x6f\x76\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x20\x46\x69\x6c\x65\x20\x6e\x6f\x74\x20\x72\x65\x61\x64\x79\x20\x74\x6f\x20\x72\x65\x6d\x6f\x76\x65\x2e"
);return ((0x0974+ 3722-0x17fe));}sub deleteAllInfoFiles{Logger::debug2 (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);if ((not (Common::NXFile::directoryExists ($infoFilesDirectory)))){(my $errorString
=libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x4d\x69\x73\x73\x69\x6e\x67\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x2e\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));return;}(my $list=
libnxhs::NXGetFilesList ($infoFilesDirectory));if (($list eq (""))){
Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x41\x6c\x6c\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x3a\x20\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x3a\x20\x27"
.$infoFilesDirectory)."\x27\x20\x69\x73\x20\x65\x6d\x70\x74\x79\x2e"));}foreach my $name
 (split ( /\n/ ,$list,(0x02a3+ 5069-0x1670))){deleteInfoFile ($name);}return;}
sub deleteInfoFile{(my $filename=(shift (@_)||("")));Logger::debug2 (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x64\x65\x6c\x65\x74\x65\x49\x6e\x66\x6f\x46\x69\x6c\x65\x28"
.$filename)."\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"));if (($filename=~ /^[\d\w]{32}\.info$/ )
){(my $path=(($infoFilesDirectory.$GLOBAL::DIRECTORY_SLASH).$filename));if ((
libnxh::NXFileExists ($path)==(0x199d+ 1483-0x1f67))){if ((libnxh::NXFileRemove 
($path)!=(0x0122+ 2780-0x0bfe))){(my $errorString=libnxh::NXGetErrorString ());(my $errorNumber
=libnxh::NXGetError ());Logger::warning (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6d\x6f\x76\x65\x20\x66\x69\x6c\x65\x20\x27"
.$path)."\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20").$errorNumber).
"\x2c\x20").$errorString)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path)."\x27\x20\x72\x65\x6d\x6f\x76\x65\x64\x2e"));}}else{(my $errorString=
libnxh::NXGetErrorString ());(my $errorNumber=libnxh::NXGetError ());
Logger::debug2 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x46\x69\x6c\x65\x20\x27"
.$path).
"\x27\x20\x64\x6f\x65\x73\x6e\x74\x20\x65\x78\x69\x73\x74\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x3a\x20"
).$errorNumber)."\x2c\x20").$errorString)."\x2e"));}}return;}sub 
setInfoDirectoryPermissionByAdmin{Logger::debug (
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x73\x65\x74\x49\x6e\x66\x6f\x44\x69\x72\x65\x63\x74\x6f\x72\x79\x50\x65\x72\x6d\x69\x73\x73\x69\x6f\x6e\x42\x79\x41\x64\x6d\x69\x6e\x28\x29\x20\x63\x61\x6c\x6c\x65\x64\x2e"
);main::nxrequire (
"\x4e\x58\x53\x79\x73\x74\x65\x6d\x44\x61\x65\x6d\x6f\x6e\x73");if ((not (
NXSystemDaemons::isHttpdEnabledInLicenceAndConfig ()))){return;}if ((not (
main::effectiveUserIsAdministrator ()))){return;}if ((not (
Common::NXFile::directoryExists ($infoFilesDirectory)))){my ($errorMsg);if ((not
 (Common::NXPaths::makePath ((\$errorMsg),$infoFilesDirectory)))){
Logger::warning (((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x64\x69\x72\x65\x63\x74\x6f\x72\x79\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorMsg)
."\x2e"));return ((0x0f7f+ 2603-0x19a9));}}my ($errorNumber);my ($errorString);(my $silent
=(0x0dcc+ 4944-0x211b));(my $permissions=((($NXBits::UserReadWrite+
$NXBits::UserExecute)+$NXBits::GroupReadWrite)+$NXBits::GroupExecute));if ((
Common::NXFile::setPermissions_unix ($infoFilesDirectory,$permissions,(
\$errorNumber),(\$errorString),$silent)==(-(0x125d+ 2165-0x1ad1)))){
Logger::debug (((((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x61\x63\x63\x65\x73\x73\x20\x72\x69\x67\x68\x74\x73\x3a\x20"
.$infoFilesDirectory)."\x20\x74\x6f\x20").$permissions).
"\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$errorNumber)."\x2c\x20").
$errorString)."\x2e"));}(my $ApacheUname=(""));if (($GLOBAL::ApacheUname ne ("")
)){($ApacheUname=$GLOBAL::ApacheUname);}else{(my (@htdUsers)=
NXTools::getNXHtdUser ());($ApacheUname=$htdUsers[(0x13d6+ 3947-0x2341)]);}(my $uid
=Common::NXCore::userInfoGetUidByUsername ($ApacheUname));(my $gid=
Common::NXCore::userInfoGetGidByUsername ("\x6e\x78"));if ((
Common::NXFile::setOwnershipForUser_unix ($infoFilesDirectory,$uid,$gid,(
\$errorString),(\$errorNumber),$silen)==(-(0x0e4b+ 4717-0x20b7)))){Logger::debug
 (((((((
"\x4e\x58\x57\x65\x62\x49\x6e\x66\x6f\x46\x69\x6c\x65\x73\x43\x6f\x6e\x74\x72\x6f\x6c\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x63\x68\x61\x6e\x67\x65\x20\x6f\x77\x6e\x65\x72\x20\x6f\x66\x20"
.$infoFilesDirectory)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").
$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return;}"\x3f\x3f\x3f";
